@@ -15,17 +15,17 @@
         <translation>CHECK-IN DETAYLARI</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Checkin.qml" line="210"/>
+        <location filename="../qml/pages/Checkin.qml" line="223"/>
         <source>TOTAL POINTS</source>
         <translation>TOPLAM PUAN</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Checkin.qml" line="251"/>
+        <location filename="../qml/pages/Checkin.qml" line="261"/>
         <source>EARNED BADGES</source>
         <translation>ROZETLERIN</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Checkin.qml" line="273"/>
+        <location filename="../qml/pages/Checkin.qml" line="283"/>
         <source>COMMENTS</source>
         <translation>YORUMLAR</translation>
     </message>
@@ -53,22 +53,22 @@
         <translation>Aklından ne geçiyor?</translation>
     </message>
     <message>
-        <location filename="../qml/pages/CheckinDialog.qml" line="124"/>
+        <location filename="../qml/pages/CheckinDialog.qml" line="129"/>
         <source>Sharing options</source>
         <translation>Paylaşım Seçenekleri</translation>
     </message>
     <message>
-        <location filename="../qml/pages/CheckinDialog.qml" line="128"/>
+        <location filename="../qml/pages/CheckinDialog.qml" line="133"/>
         <source>Share with Friends</source>
         <translation>Arkadaşlarınla Paylaş</translation>
     </message>
     <message>
-        <location filename="../qml/pages/CheckinDialog.qml" line="136"/>
+        <location filename="../qml/pages/CheckinDialog.qml" line="141"/>
         <source>Post to Facebook</source>
         <translation>Facebook&apos;da Paylaş</translation>
     </message>
     <message>
-        <location filename="../qml/pages/CheckinDialog.qml" line="144"/>
+        <location filename="../qml/pages/CheckinDialog.qml" line="149"/>
         <source>Post to Twitter</source>
         <translation>Twitter&apos;da Paylaş</translation>
     </message>
@@ -99,12 +99,12 @@
         <translation>Yeni harika yorum</translation>
     </message>
     <message>
-        <location filename="../qml/components/CommentDialog.qml" line="64"/>
+        <location filename="../qml/components/CommentDialog.qml" line="69"/>
         <source>Comment!</source>
         <translation>Yorum Yap!</translation>
     </message>
     <message>
-        <location filename="../qml/components/CommentDialog.qml" line="72"/>
+        <location filename="../qml/components/CommentDialog.qml" line="77"/>
         <source>Cancel</source>
         <translation>İptal</translation>
     </message>
@@ -160,32 +160,32 @@ You can help with resolution.</source>
 <context>
     <name>FriendsFeed</name>
     <message>
-        <location filename="../qml/pages/FriendsFeed.qml" line="44"/>
+        <location filename="../qml/pages/FriendsFeed.qml" line="43"/>
         <source>FRIENDS FEED</source>
         <translation>AKIŞ</translation>
     </message>
     <message>
-        <location filename="../qml/pages/FriendsFeed.qml" line="217"/>
+        <location filename="../qml/pages/FriendsFeed.qml" line="221"/>
         <source>RECENT</source>
         <translation>HENÜZ</translation>
     </message>
     <message>
-        <location filename="../qml/pages/FriendsFeed.qml" line="230"/>
+        <location filename="../qml/pages/FriendsFeed.qml" line="234"/>
         <source>NEARBY</source>
         <translation>YAKINDA</translation>
     </message>
     <message>
-        <location filename="../qml/pages/FriendsFeed.qml" line="251"/>
+        <location filename="../qml/pages/FriendsFeed.qml" line="255"/>
         <source>Load More</source>
         <translation>Daha Fazla Yükle</translation>
     </message>
     <message>
-        <location filename="../qml/pages/FriendsFeed.qml" line="398"/>
+        <location filename="../qml/pages/FriendsFeed.qml" line="402"/>
         <source>Sorry, Pages are not supported yet :(</source>
         <translation>Üzgünüm, Sayfalar henüz desteklenmiyor :(</translation>
     </message>
     <message>
-        <location filename="../qml/pages/FriendsFeed.qml" line="468"/>
+        <location filename="../qml/pages/FriendsFeed.qml" line="472"/>
         <source>Sorry, no lists support yet :(</source>
         <translation>Üzgünüm, listeler henüz desteklenmiyor :(</translation>
     </message>
@@ -295,12 +295,12 @@ You can help with resolution.</source>
 <context>
     <name>PhotoAdd</name>
     <message>
-        <location filename="../qml/pages/PhotoAdd.qml" line="17"/>
+        <location filename="../qml/pages/PhotoAdd.qml" line="18"/>
         <source>Select photo for upload</source>
         <translation>Yükleme için fotoğraf seçin</translation>
     </message>
     <message>
-        <location filename="../qml/pages/PhotoAdd.qml" line="123"/>
+        <location filename="../qml/pages/PhotoAdd.qml" line="56"/>
         <source>Error uploading photo!</source>
         <translation>Fotoğraf yükleme hatası!</translation>
     </message>
@@ -308,37 +308,37 @@ You can help with resolution.</source>
 <context>
     <name>PhotoShareDialog</name>
     <message>
-        <location filename="../qml/components/PhotoShareDialog.qml" line="37"/>
-        <source>Selected photo</source>
-        <translation>Seçilen resim</translation>
+        <location filename="../qml/pages/PhotoShareDialog.qml" line="20"/>
+        <source>PHOTO UPLOAD</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../qml/components/PhotoShareDialog.qml" line="59"/>
-        <source>Sharing</source>
-        <translation>Paylaşım</translation>
+        <location filename="../qml/pages/PhotoShareDialog.qml" line="36"/>
+        <source>UPLOAD</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../qml/components/PhotoShareDialog.qml" line="63"/>
+        <location filename="../qml/pages/PhotoShareDialog.qml" line="86"/>
+        <source>Sharing options</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../qml/pages/PhotoShareDialog.qml" line="90"/>
         <source>Public</source>
         <translation>Herkes</translation>
     </message>
     <message>
-        <location filename="../qml/components/PhotoShareDialog.qml" line="70"/>
-        <source>Facebook</source>
-        <translation>Facebook</translation>
+        <location filename="../qml/pages/PhotoShareDialog.qml" line="97"/>
+        <source>Post to Facebook</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../qml/components/PhotoShareDialog.qml" line="77"/>
-        <source>Twitter</source>
-        <translation>Twitter</translation>
+        <location filename="../qml/pages/PhotoShareDialog.qml" line="104"/>
+        <source>Post to Twitter</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../qml/components/PhotoShareDialog.qml" line="92"/>
-        <source>Upload photo</source>
-        <translation>Resim yükle</translation>
-    </message>
-    <message>
-        <location filename="../qml/components/PhotoShareDialog.qml" line="105"/>
+        <location filename="../qml/pages/PhotoShareDialog.qml" line="48"/>
         <source>Cancel</source>
         <translation>İptal</translation>
     </message>
@@ -588,130 +588,178 @@ You can help with resolution.</source>
     </message>
     <message>
         <location filename="../qml/pages/Settings.qml" line="387"/>
+        <source>STARTUP PAGE</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../qml/pages/Settings.qml" line="409"/>
+        <source>Feed</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../qml/pages/Settings.qml" line="415"/>
+        <source>Venues</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../qml/pages/Settings.qml" line="420"/>
+        <source>Self</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../qml/pages/Settings.qml" line="426"/>
         <source>LANGUAGE</source>
         <translation>DİL</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="398"/>
+        <location filename="../qml/pages/Settings.qml" line="437"/>
         <source>MAP PROVIDER</source>
         <translation>HARITA SAĞLAYICI</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="421"/>
+        <location filename="../qml/pages/Settings.qml" line="460"/>
         <source>Nokia</source>
         <translation>Nokia</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="427"/>
+        <location filename="../qml/pages/Settings.qml" line="466"/>
         <source>Google</source>
         <translation>Google</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="432"/>
+        <location filename="../qml/pages/Settings.qml" line="471"/>
         <source>OSM</source>
         <translation>OSM</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="450"/>
+        <location filename="../qml/pages/Settings.qml" line="489"/>
         <source>IMAGE LOADING</source>
         <translation>RESİM YÜKLENİYOR</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="469"/>
+        <location filename="../qml/pages/Settings.qml" line="508"/>
         <source>All</source>
         <translation>Hepsi</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="474"/>
+        <location filename="../qml/pages/Settings.qml" line="513"/>
         <source>Cached</source>
         <translation>Bellekte</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="480"/>
+        <location filename="../qml/pages/Settings.qml" line="519"/>
         <source>INTEGRATION WITH APPS</source>
         <translation>UYGULAMA BAĞLANTILARI</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="486"/>
+        <location filename="../qml/pages/Settings.qml" line="525"/>
         <source>Download MOLO.ME</source>
         <translation>MOLO.ME &apos;yi indir</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="505"/>
+        <location filename="../qml/pages/Settings.qml" line="544"/>
         <source>MOLO.ME Photos</source>
         <translation>MOLO.ME Fotoğrafları</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="525"/>
+        <location filename="../qml/pages/Settings.qml" line="564"/>
         <source>APPLICATION CACHE</source>
         <translation>UYGULAMA BELLEĞİ</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="533"/>
+        <location filename="../qml/pages/Settings.qml" line="572"/>
         <source>Clear</source>
         <translation>Temizle</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="545"/>
+        <location filename="../qml/pages/Settings.qml" line="584"/>
         <source>Size: %1</source>
         <translation>Boyut: %1</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="550"/>
+        <location filename="../qml/pages/Settings.qml" line="590"/>
+        <source>UI</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../qml/pages/Settings.qml" line="593"/>
+        <source>Reload UI</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../qml/pages/Settings.qml" line="599"/>
         <source>AUTHENTICATION</source>
         <translation>KİMLİK KAYDI</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="553"/>
+        <location filename="../qml/pages/Settings.qml" line="602"/>
         <source>Reset authentication</source>
         <translation>Kimlik kaydını sıfırla</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="574"/>
+        <location filename="../qml/pages/Settings.qml" line="623"/>
         <source>ACCESS RATE LIMIT</source>
         <translation>ERİŞİM ORA LİMİTİ</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="580"/>
+        <location filename="../qml/pages/Settings.qml" line="629"/>
         <source>API requests available: %1 / %2</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="586"/>
+        <location filename="../qml/pages/Settings.qml" line="635"/>
         <source>You are low on X-RATE requests</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="591"/>
+        <location filename="../qml/pages/Settings.qml" line="640"/>
         <source>DEBUG</source>
         <translation>DEBUG</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="597"/>
+        <location filename="../qml/pages/Settings.qml" line="643"/>
+        <source>Enable debug</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../qml/pages/Settings.qml" line="657"/>
         <source>Options will be available soon</source>
         <translation>Seçenekler yakında eklenecek</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="610"/>
+        <location filename="../qml/pages/Settings.qml" line="672"/>
         <source>General</source>
         <translation>Genel</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="611"/>
+        <location filename="../qml/pages/Settings.qml" line="673"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="612"/>
+        <location filename="../qml/pages/Settings.qml" line="674"/>
         <source>Service</source>
         <translation>Servis</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Settings.qml" line="613"/>
+        <location filename="../qml/pages/Settings.qml" line="675"/>
         <source>Debug</source>
         <translation>Debug</translation>
     </message>
 </context>
+<context>
+    <name>SpecialsList</name>
+    <message>
+        <location filename="../qml/components/SpecialsList.qml" line="13"/>
+        <source>VENUE SPECIALS</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../qml/components/SpecialsList.qml" line="31"/>
+        <source>Unlocked!</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>TipDialog</name>
     <message>
@@ -720,12 +768,12 @@ You can help with resolution.</source>
         <translation>Tavsiye bırakın</translation>
     </message>
     <message>
-        <location filename="../qml/components/TipDialog.qml" line="66"/>
+        <location filename="../qml/components/TipDialog.qml" line="71"/>
         <source>ADD</source>
         <translation>EKLE</translation>
     </message>
     <message>
-        <location filename="../qml/components/TipDialog.qml" line="74"/>
+        <location filename="../qml/components/TipDialog.qml" line="79"/>
         <source>Cancel</source>
         <translation>İptal</translation>
     </message>
@@ -883,47 +931,47 @@ You can help with resolution.</source>
 <context>
     <name>Venue</name>
     <message>
-        <location filename="../qml/pages/Venue.qml" line="131"/>
+        <location filename="../qml/pages/Venue.qml" line="143"/>
         <source>VENUE PHOTOS</source>
         <translation>MEKAN FOTOĞRAFLARI</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Venue.qml" line="239"/>
+        <location filename="../qml/pages/Venue.qml" line="251"/>
         <source>CHECK-IN HERE!</source>
         <translation>CHECK-IN YAP!</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Venue.qml" line="261"/>
+        <location filename="../qml/pages/Venue.qml" line="273"/>
         <source>Venue doesn&apos;t have mayor yet!</source>
         <translation>Bu mekanın henüz Mayor&apos;u yok!</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Venue.qml" line="262"/>
+        <location filename="../qml/pages/Venue.qml" line="274"/>
         <source>is the mayor.</source>
         <translation>Mayor.</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Venue.qml" line="262"/>
+        <location filename="../qml/pages/Venue.qml" line="274"/>
         <source>It could be you!</source>
         <translation>Sen olabilirsin!</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Venue.qml" line="263"/>
+        <location filename="../qml/pages/Venue.qml" line="275"/>
         <source>%1 checkins</source>
         <translation>%1 Check-in&apos;ler</translation>
     </message>
     <message>
-        <location filename="../qml/pages/Venue.qml" line="309"/>
+        <location filename="../qml/pages/Venue.qml" line="317"/>
         <source>BEST TIPS</source>
         <translation>EN İYİ TAVSİYELER</translation>
     </message>
 </context>
 <context>
-    <name>VenueEdit</name>
+    <name>VenueAdd</name>
     <message>
-        <location filename="../qml/pages/VenueEdit.qml" line="91"/>
+        <location filename="../qml/pages/VenueAdd.qml" line="91"/>
         <source>Venue name</source>
-        <translation>Mekan adı</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -942,17 +990,17 @@ You can help with resolution.</source>
         <translation>YAKIN MEKANLAR</translation>
     </message>
     <message>
-        <location filename="../qml/pages/VenuesList.qml" line="47"/>
-        <source>Add new venue</source>
-        <translation>Yeni mekan ekle</translation>
+        <location filename="../qml/pages/VenuesList.qml" line="67"/>
+        <source>GPS signal is fuzzy, cannot get your location</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../qml/pages/VenuesList.qml" line="101"/>
+        <location filename="../qml/pages/VenuesList.qml" line="96"/>
         <source>Tap to search place...</source>
         <translation>Arama yapmak için dokun...</translation>
     </message>
     <message>
-        <location filename="../qml/pages/VenuesList.qml" line="112"/>
+        <location filename="../qml/pages/VenuesList.qml" line="107"/>
         <source>SEARCH</source>
         <translation>ARA</translation>
     </message>
