@@ -57,7 +57,8 @@ users.parseUserBoard = function(response, page) {
             page.userLeadersboardRank = ranking.rank;
             page.boardModel.append({
                "user": "#" + ranking.rank + ". " +makeUserName(ranking.user),
-               "shout": "<b>"+ranking.scores.recent+" "+"points" + "</b> " + ranking.scores.checkinsCount + " " + "checkins",
+               "scoreRecent": ranking.scores.recent,
+               "checkinCount": ranking.scores.checkinsCount,
                "photo": thumbnailPhoto(ranking.user.photo,100),
         });
     });
@@ -303,10 +304,10 @@ users.parseCheckinHistory = function(response, page) {
     });
 }
 
-users.loadLikeUsers = function(page, objectid, objecttype) {
+users.loadLikeUsers = function(page, objectid, objecttype, limit) {
     page.usersModel.clear();
     page.waiting_show();
-    var url = objecttype + "s/" + objectid + "/likes?" + getAccessTokenParameter();
+    var url = objecttype + "s/" + objectid + "/likes?limit=" + limit + "&" + getAccessTokenParameter();
     api.request("GET", url, page, users.parseLikeUsers);
 }
 
